Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1725)

Unified Diff: remoting/client/rectangle_update_decoder.h

Issue 10454018: MessageLoopProxy cleanups in remoting client. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/client/plugin/pepper_xmpp_proxy.cc ('k') | remoting/client/rectangle_update_decoder.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/client/rectangle_update_decoder.h
diff --git a/remoting/client/rectangle_update_decoder.h b/remoting/client/rectangle_update_decoder.h
index eee0e760ae15807432f2f6fc6b0564e8fc668e74..557aee2785c1f1f9cf6118b992d5c31dded9077c 100644
--- a/remoting/client/rectangle_update_decoder.h
+++ b/remoting/client/rectangle_update_decoder.h
@@ -15,7 +15,7 @@
#include "remoting/client/frame_producer.h"
namespace base {
-class MessageLoopProxy;
+class SingleThreadTaskRunner;
} // namespace base
namespace pp {
@@ -33,14 +33,15 @@ class SessionConfig;
// TODO(ajwong): Re-examine this API, especially with regards to how error
// conditions on each step are reported. Should they be CHECKs? Logs? Other?
// TODO(sergeyu): Rename this class.
-class RectangleUpdateDecoder :
- public base::RefCountedThreadSafe<RectangleUpdateDecoder>,
- public FrameProducer {
+class RectangleUpdateDecoder
+ : public base::RefCountedThreadSafe<RectangleUpdateDecoder>,
+ public FrameProducer {
public:
// Creates an update decoder on |message_loop_|, outputting to |consumer|.
// TODO(wez): Replace the ref-counted proxy with an owned FrameConsumer.
- RectangleUpdateDecoder(scoped_refptr<base::MessageLoopProxy> message_loop,
- scoped_refptr<FrameConsumerProxy> consumer);
+ RectangleUpdateDecoder(
+ scoped_refptr<base::SingleThreadTaskRunner> task_runner,
+ scoped_refptr<FrameConsumerProxy> consumer);
// Initializes decoder with the information from the protocol config.
void Initialize(const protocol::SessionConfig& config);
@@ -67,7 +68,7 @@ class RectangleUpdateDecoder :
void SchedulePaint();
void DoPaint();
- scoped_refptr<base::MessageLoopProxy> message_loop_;
+ scoped_refptr<base::SingleThreadTaskRunner> task_runner_;
scoped_refptr<FrameConsumerProxy> consumer_;
scoped_ptr<Decoder> decoder_;
« no previous file with comments | « remoting/client/plugin/pepper_xmpp_proxy.cc ('k') | remoting/client/rectangle_update_decoder.cc » ('j') | no next file with comments »
@@ -33,14 +33,15 @@ class SessionConfig;
public:
- // Creates an update decoder on |message_loop_|, outputting to |consumer|.
+ // Creates an update decoder on |task_runner_|, outputting to |consumer|.
// TODO(wez): Replace the ref-counted proxy with an owned FrameConsumer.

Powered by Google App Engine
This is Rietveld 408576698